@@ -31,46 +31,39 @@ void KBlocksGameRecorder::append(int index, int type, int value)
     mGameRecord.push_back(tmpLastData);
 }
 
-void KBlocksGameRecorder::save(const char * fileName, bool isBinaryMode)
+void KBlocksGameRecorder::save(const char *fileName, bool isBinaryMode)
 {
-    FILE * pFile = fopen(fileName, "w");
-    if (isBinaryMode)
-    {
+    FILE *pFile = fopen(fileName, "w");
+    if (isBinaryMode) {
         saveBinary(pFile);
-    }
-    else
-    {
+    } else {
         saveText(pFile);
     }
     fclose(pFile);
 }
 
-void KBlocksGameRecorder::saveText(FILE * pFile)
+void KBlocksGameRecorder::saveText(FILE *pFile)
 {
     int tmpTime = 0;
     timeLong oldTime = mGameRecord.front().time;
     list<_game_record_data>::iterator it;
-    for(it = mGameRecord.begin(); it != mGameRecord.end(); ++it)
-    {
+    for (it = mGameRecord.begin(); it != mGameRecord.end(); ++it) {
         tmpTime = (int)(it->time - oldTime);
         oldTime = it->time;
         fprintf(pFile, "%d %s %d %d\n", tmpTime, KBlocksRecordText[it->type], it->index, it->value);
     }
 }
 
-void KBlocksGameRecorder::saveBinary(FILE * pFile)
+void KBlocksGameRecorder::saveBinary(FILE *pFile)
 {
     int tmpTime = 0;
     timeLong oldTime = mGameRecord.front().time;
     list<_game_record_data>::iterator it;
-    for(it = mGameRecord.begin(); it != mGameRecord.end(); ++it)
-    {
+    for (it = mGameRecord.begin(); it != mGameRecord.end(); ++it) {
         tmpTime = (int)(it->time - oldTime);
         oldTime = it->time;
-        if (tmpTime > 255)
-        {
-            while(tmpTime > 255)
-            {
+        if (tmpTime > 255) {
+            while (tmpTime > 255) {
                 writeByte(pFile, 255);
                 writeByte(pFile, RecordDataType_Skipped);
                 writeByte(pFile, it->index);
@@ -85,7 +78,7 @@ void KBlocksGameRecorder::saveBinary(FILE * pFile)
     }
 }
 
-void KBlocksGameRecorder::writeByte(FILE * pFile, int value)
+void KBlocksGameRecorder::writeByte(FILE *pFile, int value)
 {
     int tmpByte = (value & 0xFF);
     fputc(tmpByte, pFile);
@@ -94,11 +87,11 @@ void KBlocksGameRecorder::writeByte(FILE * pFile, int value)
 timeLong KBlocksGameRecorder::getMillisecOfNow()
 {
     timeval tmpCurTime;
-    
+
     gettimeofday(&tmpCurTime, NULL);
-    
+
     timeLong tmpMilliTime = (timeLong)tmpCurTime.tv_usec / 1000;
     tmpMilliTime += (timeLong)tmpCurTime.tv_sec * 1000;
-    
+
     return tmpMilliTime;
 }
